library(tidyverse)
library(metafor)

# Read abs_bhl.csv data
# Create Forest Plot

abs <- read.csv('abs_bhl.csv',header=T)
abs.reg <- rma(data=abs,yi,vi,slab=Region)
abs.reg

png('ABS_Forest.png',width=6,height=4,units='in',res=600)
par(mar=c(4,4,0,1)+0.1)
forest(abs.reg,atransf=exp,mlab='Summary Estimate',
       xlab='Relative Change in Cycling After Bicycle Helmet Law',
       at=log(c(0.67,0.8,1,1.25,1.5)),xlim=c(-1,1))
text(-1,10,'State/Territory',pos=4,font=2)
text(1,10,'Relative Change [95% CI]',pos=2,font=2)
dev.off()

# Pucher Plot

pucher <- read.csv('pucher.csv',header=T)

p.pucher <- ggplot(pucher,aes(x=Country,y=Percentage)) +
  geom_bar(stat='identity') +
  geom_text(aes(label=Percentage), vjust=-0.25, color="black",
            position = position_dodge(width=0.9), size=3.5) +
  ylim(0,30) +
  theme_bw() +
  theme(axis.text.x = element_text(angle = 90)) 
p.pucher

ggsave('pucher_data_plot.png',p.pucher,device='png',width=5,height=3,units='in',dpi=600)

# Australian Cycling Plot

Oz <- read.csv('oz_bike_data_long.csv',header=T)

p.oz <- ggplot(Oz,aes(x=Year,y=Percentage,color=Data)) +
  geom_point(aes(shape=Data)) +
  geom_line(aes(linetype=Data)) +
  ylim(0,45) +
  theme_bw() +
  theme(legend.position='bottom',legend.text=element_text(size=rel(0.7))) +
  scale_colour_grey(start=0,end=0.5)
p.oz

ggsave('oz_bike_data.png',p.oz,device='png',width=5,height=3,units='in',dpi=600)

